@@ -3,17 +3,13 @@ use strict;
 use warnings;
 use utf8;
 use Text::Xslate;
-use File::ShareDir qw(dist_dir);
 use List::Util qw(first);
-use Data::Thunk qw(lazy);
+use File::Spec;
 
 sub make_instance {
     my ($class, $c) = @_;
 
-    my $path = first { -d $_ } (
-        lazy { File::Spec->catfile($c->base_dir, 'share/tmpl') },
-        lazy { File::ShareDir::dist_dir('Ukigumo-Agent', 'tmpl') },
-    );
+    my $path = File::Spec->catdir($c->share_dir, 'tmpl');
     my $xslate = Text::Xslate->new(
         syntax => 'TTerse',
         path => ["$path"],
